from fastapi.security import OAuth2PasswordRequestForm
from fastapi import APIRouter, Depends
from bson.objectid import ObjectId
from server.service.jwttoken import create_access_token
from server.service.oauth import get_current_shop
from server.service.database import get_connection
from server.mock.model import Shop_helper
from server.mock.schemas import Shop

collection = get_connection("shop")
shop = APIRouter()

@shop.get("/shop")
async def get_shop():
    return [Shop_helper(i) for i in collection.find()]

@shop.get("/shop/{id}")
async def get_shop_by_id(id: str):
    shop = collection.find_one({"_id": ObjectId(id)})
    return Shop_helper(shop)

@shop.post("/shop")
async def create_shop(shop: Shop):
    payload = {
        "name": shop.name,
        "email": shop.email,
        "tel": shop.tel,
        "owner": shop.owner,
        "secret": shop.secret
    }
    collection.insert_one(payload)
    return [Shop_helper(i) for i in collection.find()]

@shop.patch("/shop/{id}")
async def update_shop(id: str, shop: Shop):
    payload = {
        "name": shop.name,
        "email": shop.email,
        "tel": shop.tel,
        "owner": shop.owner
    }
    collection.update_one({"_id": ObjectId(id)}, {"$set": payload})
    return [Shop_helper(i) for i in collection.find()]

@shop.delete("/shop/{id}")
async def delete_shop(id: str):
    collection.delete_one({"_id": ObjectId(id)})
    return [Shop_helper(i) for i in collection.find()]

@shop.post("/shop_login")
async def login_shop(req: OAuth2PasswordRequestForm = Depends()):
    secret = req.password
    shop_account = collection.find_one({"secret": secret})
    if shop_account is None:
        return {"error": "Account not found"}
    format_shop = Shop_helper(shop_account)
    access_token = create_access_token({"id": format_shop["id"], "owner": format_shop["owner"], "name": format_shop["name"]})
    return {"access_token":access_token, "token_type": "Bearer"}

@shop.get("/shop_verify_account")
async def verify_shop_account(current_shop: Shop = Depends(get_current_shop)):
    return current_shop
    